@@ -204,7 +204,7 @@ void linkfiles(file_t *files, const int linktype, const int only_current)
         }
 
         /* Do not attempt to hard link files for which we don't have write access */
-	if (
+        if (
 #ifdef ON_WINDOWS
         !JC_S_ISRO(dupelist[x]->mode) &&
 #endif
@@ -347,10 +347,23 @@ void linkfiles(file_t *files, const int linktype, const int only_current)
             jc_fwprint(stdout, dupelist[x]->d_name, 1);
           }
 #ifndef NO_HASHDB
-          /* Delete the hashdb entry for new hard/symbolic links */
-          if (linktype != 2 && ISFLAG(flags, F_HASHDB)) {
-            dupelist[x]->mtime = 0;
-            add_hashdb_entry(NULL, 0, dupelist[x]);
+          if (ISFLAG(flags, F_HASHDB)) {
+            /* Delete hashdb entry for symlinks - the original file is gone */
+            switch (linktype) {
+              case 0:
+                dupelist[x]->mtime = -1;
+                add_hashdb_entry(NULL, 0, dupelist[x], 0);
+                break;
+              case 1:
+		/* Copy hard link source info to link target and update hashdb */
+                dupelist[x]->filehash_partial = srcfile->filehash_partial;
+                dupelist[x]->filehash = srcfile->filehash;
+                dupelist[x]->mtime = srcfile->mtime;
+                dupelist[x]->inode = srcfile->inode;
+                dupelist[x]->flags |= FF_HASHDB_DIRTY | (srcfile->flags & (FF_HASH_PARTIAL | FF_HASH_FULL));
+                add_hashdb_entry(NULL, 0, dupelist[x], 1);
+              default:
+            }
           }
 #endif
         } else {
