@@ -26,7 +26,7 @@ typedef struct _hashdb {
 } hashdb_t;
 
 extern int save_hash_database(const char * const restrict dbname, const int destroy);
-extern hashdb_t *add_hashdb_entry(char *in_path, const int in_pathlen, const file_t *check);
+extern hashdb_t *add_hashdb_entry(char *in_path, const int in_pathlen, const file_t *check, int update);
 extern int64_t load_hash_database(const char * const restrict dbname);
 extern int read_hashdb_entry(file_t *file);
 extern uint64_t dump_hashdb(void);
