@@ -10,6 +10,8 @@ extern "C" {
 
 void version_text(int short_version);
 void help_text(void);
+void help_text_extfilter(void);
+void help_text_chunksize(void);
 
 #ifdef __cplusplus
 }
