@@ -141,7 +141,7 @@ char tempname[JC_PATHBUF_SIZE * 2];
 const char *s_interrupt = "\nStopping file scan due to user abort\n";
 const char *s_no_dupes = "No duplicates found.\n";
 const char *s_help = "help";
-const char *s_chunksize_help = "         Run 'jdupes -C help' or info on the new size specifications.\n\n";
+const char *s_chunksize_help = "         Run 'jdupes -C help' for info on the new size specifications.\n\n";
 
 /* Exit status; use exit() codes for setting this */
 int exit_status = EXIT_SUCCESS;
@@ -192,6 +192,7 @@ int main(int argc, char **argv)
     { "", 0, 0, '9' },
     { "no-hidden", 0, 0, 'A' },
     { "dedupe", 0, 0, 'B' },
+    { "hash-db-opts", 1, 0, 'b' },
     { "chunk-size", 1, 0, 'C' },
     { "debug", 0, 0, 'D' },
     { "delete", 0, 0, 'd' },
@@ -236,7 +237,7 @@ int main(int argc, char **argv)
  #define GETOPT getopt
 #endif
 
-#define GETOPT_STRING "@019ABC:DdEefHhIijKLlMmNnOo:P:pQqRrSsTtUuVvX:Yy:Zz"
+#define GETOPT_STRING "@019ABb:C:DdEefHhIijKLlMmNnOo:P:pQqRrSsTtUuVvX:Yy:Zz"
 
   /* Verify libjodycode compatibility before going further */
   if (libjodycode_version_check(1, 0) != 0) {
@@ -244,25 +245,19 @@ int main(int argc, char **argv)
     exit(EXIT_FAILURE);
   }
 
-/* Windows buffers our stderr output; don't let it do that */
+/* On Windows, set up the terminal and un-wide argv */
 #ifdef ON_WINDOWS
-  if (setvbuf(stderr, NULL, _IONBF, 0) != 0)
-    fprintf(stderr, "warning: setvbuf() failed\n");
-#endif
-
-#ifdef UNICODE
-  /* Create a UTF-8 **argv from the wide version */
+ #ifdef UNICODE
   static char **argv;
-  int wa_err;
-  argv = (char **)malloc(sizeof(char *) * (size_t)argc);
-  if (!argv) jc_oom("main() unicode argv");
-  wa_err = jc_widearg_to_argv(argc, wargv, &argv);
-  if (wa_err != 0) {
-    jc_print_error(wa_err);
+  int ut_err = jc_setup_unicode_terminal(argc, wargv, &argv, NULL);
+ #else
+  int ut_err = jc_setup_unicode_terminal(0, NULL, NULL, NULL);
+ #endif /* UNICODE */
+  if (ut_err != 0) {
+    jc_print_error(ut_err);
     exit(EXIT_FAILURE);
   }
-  jc_set_output_modes(JC_MODE_UTF16_TTY, JC_MODE_UTF16_TTY);
-#endif /* UNICODE */
+#endif /* ON_WINDOWS */
 
 #ifndef NO_CHUNKSIZE
   /* Auto-tune chunk size to be half of L1 data cache if possible */
@@ -333,6 +328,10 @@ int main(int argc, char **argv)
       LOUD(fprintf(stderr, "opt: CoW/block-level deduplication enabled (--dedupe)\n");)
       break;
 #endif /* ENABLE_DEDUPE */
+#ifndef NO_HASHDB
+    case 'b':
+      break;
+#endif /* NO_HASHDB */
 #ifndef NO_CHUNKSIZE
     case 'C':
       errno = 0;
@@ -341,14 +340,14 @@ int main(int argc, char **argv)
       if (errno != 0 || manual_chunk_size < 0 || manual_chunk_size > MAX_CHUNK_OPT_SIZE) {
         fprintf(stderr, "error: -C/--chunk-size '%s' invalid or out of range\n", optarg);
         fprintf(stderr, "%s", s_chunksize_help);
-	exit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
       }
       fprintf(stderr, "\nWARNING: The -C/--chunk-size parameter has changed!\n");
       fprintf(stderr, "%s", s_chunksize_help);
       auto_chunk_size = chunk_opt_size[manual_chunk_size];
       fprintf(stderr, "note: the user-selected I/O chunk size is ");
-      if (auto_chunk_size <= 524288) fprintf(stderr, "%lld KiB\n", auto_chunk_size / 1024);
-      if (auto_chunk_size > 524288) fprintf(stderr, "%lld MiB\n", auto_chunk_size / 1048576);
+      if (auto_chunk_size <= 524288) fprintf(stderr, "%lu KiB\n", (long unsigned int)(auto_chunk_size / 1024));
+      if (auto_chunk_size > 524288) fprintf(stderr, "%lu MiB\n", (long unsigned int)(auto_chunk_size / 1048576));
       break;
 #endif /* NO_CHUNKSIZE */
 #ifndef NO_DELETE
@@ -526,10 +525,7 @@ int main(int argc, char **argv)
     case 'y':
       SETFLAG(flags, F_HASHDB);
       LOUD(fprintf(stderr, "opt: use a hash database (--hash-db)\n");)
-      fprintf(stderr, "\nWARNING: THE HASH DATABASE FEATURE IS UNDER HEAVY DEVELOPMENT! It functions\n");
-      fprintf(stderr,   "         but there are LOTS OF QUIRKS. The behavior is not fully documented\n");
-      fprintf(stderr,   "         yet and basic 'smarts' have not been implemented. USE THIS FEATURE\n");
-      fprintf(stderr,   "         AT YOUR OWN RISK. Report hashdb issues to jody@jodybruchon.com\n\n");
+      fprintf(stderr, "NOTICE: hashdb is experimental. Report issues to jody@jodybruchon.com\n");
       hdbsize = 0;
       hdblen = strlen(optarg) + 1;
       if (hdblen < 24) hdblen = 24;
@@ -744,13 +740,13 @@ skip_partialonly_noise:
         pop_filehash = get_filehash(curfile, PARTIAL_HASH_SIZE, hash_algo);
         if (pop_filehash == NULL) goto skip_full_check;
         curfile->filehash_partial = *pop_filehash;
-	pop_dirty = 1;
+        pop_dirty = 1;
       }
       if (!ISFLAG(curfile->flags, FF_HASH_FULL)) {
         pop_filehash = get_filehash(curfile, 0, hash_algo);
         if (pop_filehash == NULL) goto skip_full_check;
         curfile->filehash = *pop_filehash;
-	pop_dirty = 1;
+        pop_dirty = 1;
       }
       if (pop_dirty == 1) {
         SETFLAG(curfile->flags, FF_HASH_PARTIAL | FF_HASH_FULL | FF_HASHDB_DIRTY);
@@ -797,7 +793,7 @@ skip_partialonly_noise:
 #endif
         dupecount++;
       } else {
-	goto skip_full_check;
+        goto skip_full_check;
         DBG(hash_fail++;)
       }
     }
